@@ -1,11 +1,13 @@
 """
 Method or function argument.
 """
-from typing import Optional, Set
+from typing import Optional, Set, Type, TypeVar
 
 from mypy_boto3_builder.type_annotations.fake_annotation import FakeAnnotation
 from mypy_boto3_builder.type_annotations.type_constant import TypeConstant
 
+_R = TypeVar("_R", bound="Argument")
+
 
 class Argument:
     """
@@ -30,6 +32,13 @@ class Argument:
         self.default = default
         self.prefix = prefix
 
+    @classmethod
+    def kwflag(cls: Type[_R]) -> _R:
+        return cls("*", None)
+
+    def is_kwflag(self) -> bool:
+        return self.name == "*"
+
     def get_types(self) -> Set[FakeAnnotation]:
         types: Set[FakeAnnotation] = set()
         if self.type_annotation is not None:
